import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { isValidElementType } from 'react-is';
import { defaults } from 'lodash';
import { connect } from 'react-redux';
import { createStructuredSelector, createSelector } from 'reselect';
export default function featureComponents(options) {
  const {
    getFeatures,
    sortFeatures,
    getComponents
  } = defaults({}, options, {
    getFeatures: state => state ? state.features : {},
    sortFeatures: features => Object.values(features)
  });
  const mapStateToProps = createStructuredSelector({
    features: createSelector(getFeatures, sortFeatures)
  });
  function mergeProps({
    features
  }, dispatchProps, {
    children,
    ...props
  }) {
    const renderedComponents = [];
    features.forEach((feature, featureIndex) => {
      let components = getComponents(feature);
      if (components == null) return;
      if (!Array.isArray(components)) components = [components];
      components.forEach((Comp, index) => {
        const key = featureIndex + ':' + index;
        if ( /*#__PURE__*/React.isValidElement(Comp)) {
          renderedComponents.push( /*#__PURE__*/React.cloneElement(Comp, {
            ...props,
            key
          }));
        } else if (isValidElementType(Comp)) {
          const FeatureComponent = Comp;
          renderedComponents.push( /*#__PURE__*/React.createElement(FeatureComponent, _extends({}, props, {
            key: key
          })));
        }
      });
    });
    return {
      children: children instanceof Function ? children(renderedComponents) : /*#__PURE__*/React.createElement(React.Fragment, null, renderedComponents)
    };
  }
  mergeProps.propTypes = {
    "features": PropTypes.arrayOf(function () {
      return (typeof Feature === "function" ? PropTypes.instanceOf(Feature).isRequired : PropTypes.any.isRequired).apply(this, arguments);
    }).isRequired
  };
  const FeatureComponents = ({
    children
  }) => children;
  return connect(mapStateToProps, null, mergeProps)(FeatureComponents);
}
featureComponents.propTypes = {
  "getFeatures": PropTypes.func,
  "sortFeatures": PropTypes.func,
  "getComponents": PropTypes.func.isRequired
};
import PropTypes from "prop-types";