import * as React from 'react';
import { connect } from 'react-redux';
import { loadFeature } from 'redux-features';
import { createSelector } from 'reselect';
import { defaults } from 'lodash';
var bpfrpt_proptype_Options = {
  "getFeatures": PropTypes.func,
  "getFeatureStates": PropTypes.func,
  "featureId": PropTypes.string.isRequired,
  "render": PropTypes.func
};
export default function featureLoader(options) {
  const {
    getFeatures,
    getFeatureStates,
    featureId,
    render
  } = defaults({}, options, {
    getFeatures: state => state ? state.features : undefined,
    getFeatureStates: state => state ? state.featureStates : undefined
  });
  const mapStateToProps = createSelector(getFeatures, getFeatureStates, (features = {}, featureStates = {}) => ({
    feature: features[featureId],
    featureState: featureStates[featureId]
  }));
  function mergeProps({
    feature,
    featureState
  }, {
    dispatch
  }, props) {
    return {
      dispatch,
      featureState,
      children: render ? render({
        feature,
        featureState,
        props
      }) : null
    };
  }
  class FeatureLoader extends React.Component {
    constructor(props) {
      super(props);
      const {
        featureState,
        dispatch
      } = props;
      if (featureState === 'NOT_LOADED') dispatch(loadFeature(featureId));
    }
    render() {
      return this.props.children;
    }
  }
  return connect(mapStateToProps, null, mergeProps)(FeatureLoader);
}
import PropTypes from "prop-types";
export { bpfrpt_proptype_Options };